## ----setup, include = FALSE---------------------------------------------------
# Locally compile vignettes with eval set to TRUE
# Other machines do not compile vignettes with eval set to FALSE
if(stringr::str_detect(getwd(), "alval")){
  eval = TRUE
  # eval = FALSE
} else {
  eval = FALSE
}

knitr::opts_chunk$set(
  eval = eval,
  collapse = TRUE,
  comment = "#>",
  message = FALSE
)

## ---- eval = FALSE------------------------------------------------------------
#  source("https://neuroconductor.org/neurocLite.R")
#  neuro_install("rtapas")

## ---- eval = FALSE------------------------------------------------------------
#  # install.packages('remotes')
#  library(remotes)
#  remotes::install_github('avalcarcel9/rtapas')

## -----------------------------------------------------------------------------
#  library(rtapas)
#  library(neurobase)
#  library(oro.nifti)
#  library(aliviateR)
#  library(dplyr)
#  library(tibble)
#  library(knitr)

## -----------------------------------------------------------------------------
#  # Make a list of the gold standard masks
#  train_gold_standard_masks = list(gs1 = gs1,
#                                   gs2 = gs2,
#                                   gs3 = gs3,
#                                   gs4 = gs4,
#                                   gs5 = gs5,
#                                   gs6 = gs6,
#                                   gs7 = gs7,
#                                   gs8 = gs8,
#                                   gs9 = gs9,
#                                   gs10 = gs10)
#  
#  # Convert the gold standard masks to nifti objects
#  train_gold_standard_masks = lapply(train_gold_standard_masks, oro.nifti::nifti)

## -----------------------------------------------------------------------------
#  # Show the gold standard masks using patchwork
#  oro.nifti::image(train_gold_standard_masks$gs1) + oro.nifti::image(train_gold_standard_masks$gs2) +
#  oro.nifti::image(train_gold_standard_masks$gs3) + oro.nifti::image(train_gold_standard_masks$gs4) +
#  oro.nifti::image(train_gold_standard_masks$gs5) + oro.nifti::image(train_gold_standard_masks$gs6) +
#  oro.nifti::image(train_gold_standard_masks$gs7) + oro.nifti::image(train_gold_standard_masks$gs8) +
#  oro.nifti::image(train_gold_standard_masks$gs9) + oro.nifti::image(train_gold_standard_masks$gs10)

## -----------------------------------------------------------------------------
#  # Make a list of the training probability maps
#  train_probability_maps = list(pmap1 = pmap1,
#                                pmap2 = pmap2,
#                                pmap3 = pmap3,
#                                pmap4 = pmap4,
#                                pmap5 = pmap5,
#                                pmap6 = pmap6,
#                                pmap7 = pmap7,
#                                pmap8 = pmap8,
#                                pmap9 = pmap9,
#                                pmap10 = pmap10)
#  
#  # Convert the probability maps to nifti objects
#  train_probability_maps = lapply(train_probability_maps, oro.nifti::nifti)

## -----------------------------------------------------------------------------
#  # Show the probability maps using patchwork
#  oro.nifti::image(train_probability_maps$pmap1, col = heat.colors(100)) +
#    oro.nifti::image(train_probability_maps$pmap2, col = heat.colors(100)) +
#    oro.nifti::image(train_probability_maps$pmap3, col = heat.colors(100)) +
#    oro.nifti::image(train_probability_maps$pmap4, col = heat.colors(100)) +
#    oro.nifti::image(train_probability_maps$pmap5, col = heat.colors(100)) +
#    oro.nifti::image(train_probability_maps$pmap6, col = heat.colors(100)) +
#    oro.nifti::image(train_probability_maps$pmap7, col = heat.colors(100)) +
#    oro.nifti::image(train_probability_maps$pmap8, col = heat.colors(100)) +
#    oro.nifti::image(train_probability_maps$pmap9, col = heat.colors(100)) +
#    oro.nifti::image(train_probability_maps$pmap10, col = heat.colors(100))

## -----------------------------------------------------------------------------
#  # Make a list of the brain masks
#  train_brain_masks = list(brain_mask1 = brain_mask,
#                           brain_mask2 = brain_mask,
#                           brain_mask3 = brain_mask,
#                           brain_mask4 = brain_mask,
#                           brain_mask5 = brain_mask,
#                           brain_mask6 = brain_mask,
#                           brain_mask7 = brain_mask,
#                           brain_mask8 = brain_mask,
#                           brain_mask9 = brain_mask,
#                           brain_mask10 = brain_mask)
#  
#  # Convert the brain masks to nifti objects
#  train_brain_masks = lapply(train_brain_masks, oro.nifti::nifti)

## -----------------------------------------------------------------------------
#  train_ids = paste0('subject_', 1:length(train_gold_standard_masks))

## -----------------------------------------------------------------------------
#  # Initialize an empty list to store results created on 1 core
#  train_data1 = list()
#  
#  # Run tapas_data function
#  for(i in 1:length(train_probability_maps)){
#    train_data1[[i]] = tapas_data(thresholds = seq(from = 0, to = 1, by = 0.01),
#                           pmap = train_probability_maps[[i]],
#                           gold_standard = train_gold_standard_masks[[i]],
#                           mask = train_brain_masks[[i]],
#                           k = 0,
#                           subject_id = train_ids[[i]],
#                           verbose = TRUE)
#  }

## -----------------------------------------------------------------------------
#  # Store results created on 2 cores
#  # Run tapas_data_par function
#  train_data2 = tapas_data_par(cores = 2,
#                               thresholds = seq(from = 0, to = 1, by = 0.01),
#                               pmap = train_probability_maps,
#                               gold_standard = train_gold_standard_masks,
#                               mask = train_brain_masks,
#                               k = 0,
#                               subject_id = train_ids,
#                               ret = TRUE,
#                               outfile = NULL,
#                               verbose = TRUE)

## -----------------------------------------------------------------------------
#  # Bind the single core data across list objects (subjects)
#  train_data1 = dplyr::bind_rows(train_data1)
#  # Bind the 2 core data across list objects (subjects)
#  train_data2 = dplyr::bind_rows(train_data2)
#  # Check that datasets are equal
#  all.equal(train_data1, train_data2)

## -----------------------------------------------------------------------------
#  head(train_data1)
#  tail(train_data1)

## -----------------------------------------------------------------------------
#  tapas_model = tapas_train(data = train_data1,
#                            dsc_cutoff = 0.03,
#                            verbose = TRUE)

## -----------------------------------------------------------------------------
#  # The TAPAS GAM model
#  summary(tapas_model$tapas_model)
#  # The threshold that optimizes group-level DSC
#  tapas_model$group_threshold
#  # The lower and upper bound clamps to avoid extrapolation
#  tapas_model$clamp_data
#  # The training data for the TAPAS `mgcv::gam` function
#  tapas_model$train_data

## -----------------------------------------------------------------------------
#  make_scattergram(tapas_model = tapas_model)

## -----------------------------------------------------------------------------
#  # Testing gold standard masks
#  test_gold_standard_masks = list(gs11 = gs11,
#                                  gs12 = gs12,
#                                  gs13 = gs13,
#                                  gs14 = gs14,
#                                  gs15 = gs15)
#  
#  # Make array objects niftis
#  test_gold_standard_masks = lapply(test_gold_standard_masks, oro.nifti::nifti)
#  
#  # Visualize the testing subjects gold standard masks
#  oro.nifti::image(test_gold_standard_masks$gs11) + oro.nifti::image(test_gold_standard_masks$gs12) +
#  oro.nifti::image(test_gold_standard_masks$gs13) + oro.nifti::image(test_gold_standard_masks$gs14) +
#  oro.nifti::image(test_gold_standard_masks$gs15)

## -----------------------------------------------------------------------------
#  # Obtain the test subject probability maps
#  test_probability_maps = list(pmap11 = pmap11,
#                               pmap12 = pmap12,
#                               pmap13 = pmap13,
#                               pmap14 = pmap14,
#                               pmap15 = pmap15)
#  
#  # Make array objects niftis
#  test_probability_maps = lapply(test_probability_maps, oro.nifti::nifti)
#  
#  # Visualize the 5 testing probability maps
#  oro.nifti::image(test_probability_maps$pmap11, col = heat.colors(100)) +
#  oro.nifti::image(test_probability_maps$pmap12, col = heat.colors(100)) +
#  oro.nifti::image(test_probability_maps$pmap13, col = heat.colors(100)) +
#  oro.nifti::image(test_probability_maps$pmap14, col = heat.colors(100)) +
#  oro.nifti::image(test_probability_maps$pmap15, col = heat.colors(100))

## -----------------------------------------------------------------------------
#  # Create a list of testing brain masks
#  test_brain_masks = list(brain_mask11 = brain_mask,
#                          brain_mask12 = brain_mask,
#                          brain_mask13 = brain_mask,
#                          brain_mask14 = brain_mask,
#                          brain_mask15 = brain_mask)
#  
#  # Make array objects niftis
#  test_brain_masks = lapply(test_brain_masks, oro.nifti::nifti)

## -----------------------------------------------------------------------------
#  test_ids = paste0('subject_', (10 + 1:length(test_gold_standard_masks)))

## -----------------------------------------------------------------------------
#  # Initialize an empty list to store results created on 1 core
#  test_data1 = list()
#  
#  # Run tapas_predict function
#  for(i in 1:length(test_probability_maps)){
#    test_data1[[i]] = tapas_predict(pmap = test_probability_maps[[i]],
#                                    model = tapas_model,
#                                    clamp = TRUE,
#                                    k = 0,
#                                    verbose = TRUE)
#  }

## -----------------------------------------------------------------------------
#  # Store results created on 2 cores
#  # Run tapas_predict_par function
#  test_data2 = tapas_predict_par(cores = 2,
#                                 pmap = test_probability_maps,
#                                 subject_id = test_ids,
#                                 model = tapas_model,
#                                 clamp = TRUE,
#                                 k = 0,
#                                 ret = TRUE,
#                                 outfile = NULL,
#                                 verbose = TRUE)

## -----------------------------------------------------------------------------
#  all.equal(test_data1[[1]]$subject_threshold, test_data2[[1]]$subject_threshold)
#  all.equal(sum(test_data1[[1]]$tapas_binary_mask), sum(test_data2[[1]]$tapas_binary_mask))
#  all.equal(sum(test_data1[[1]]$group_binary_mask), sum(test_data2[[1]]$group_binary_mask))

## -----------------------------------------------------------------------------
#  names(test_data1[[1]])

## -----------------------------------------------------------------------------
#  # The TAPAS binary masks
#  oro.nifti::image(test_data1[[1]]$tapas_binary_mask) +
#    oro.nifti::image(test_data1[[2]]$tapas_binary_mask) +
#    oro.nifti::image(test_data1[[3]]$tapas_binary_mask) +
#    oro.nifti::image(test_data1[[4]]$tapas_binary_mask) +
#    oro.nifti::image(test_data1[[5]]$tapas_binary_mask)

## -----------------------------------------------------------------------------
#  # The group threshold binary masks
#  oro.nifti::image(test_data1[[1]]$group_binary_mask) +
#    oro.nifti::image(test_data1[[2]]$group_binary_mask) +
#    oro.nifti::image(test_data1[[3]]$group_binary_mask) +
#    oro.nifti::image(test_data1[[4]]$group_binary_mask) +
#    oro.nifti::image(test_data1[[5]]$group_binary_mask)

## -----------------------------------------------------------------------------
#  # Calculate DSC in each mask
#  dsc = tibble::tibble(
#    tapas_dsc = c(aliviateR::dsc(test_gold_standard_masks[[1]], test_data1[[1]]$tapas_binary_mask),
#                  aliviateR::dsc(test_gold_standard_masks[[2]], test_data1[[2]]$tapas_binary_mask),
#                  aliviateR::dsc(test_gold_standard_masks[[3]], test_data1[[3]]$tapas_binary_mask),
#                  aliviateR::dsc(test_gold_standard_masks[[4]], test_data1[[4]]$tapas_binary_mask),
#                  aliviateR::dsc(test_gold_standard_masks[[5]], test_data1[[5]]$tapas_binary_mask)),
#    group_dsc = c(aliviateR::dsc(test_gold_standard_masks[[1]], test_data1[[1]]$group_binary_mask),
#                  aliviateR::dsc(test_gold_standard_masks[[2]], test_data1[[2]]$group_binary_mask),
#                  aliviateR::dsc(test_gold_standard_masks[[3]], test_data1[[3]]$group_binary_mask),
#                  aliviateR::dsc(test_gold_standard_masks[[4]], test_data1[[4]]$group_binary_mask),
#                  aliviateR::dsc(test_gold_standard_masks[[5]], test_data1[[5]]$group_binary_mask)))
#  # Print DSC
#  dsc

## ---- fig.align="center", echo = FALSE----------------------------------------
#  knitr::include_graphics("../man/figures/end.jpg")

